==> 1.0.8.zip: grafana-data-exporter-app/README.md <==
# Grafana Data Exporter App

Grafana plugin for exporting data from Grafana panels as CSV.

Supported datasources:
- MySQL
- PostgreSQL

## Prerequisites
- [Grafana 9.0.0+](https://grafana.com/grafana/download)
- [Grafana Data Exporter](https://code.corpglory.net/corpglory/grafana-data-exporter)
- set Grafana `app_mode` as `development`:
  - find the configuration file: [https://grafana.com/docs/grafana/latest/setup-grafana/configure-grafana/#configuration-file-location](https://grafana.com/docs/grafana/latest/setup-grafana/configure-grafana/#configuration-file-location)
  - change `app_mode = production` to `app_mode = development`
  - restart Grafana

## Plugin installation

The easiest way to install plugins is by using the `grafana-cli` tool which is bundled with Grafana. See [Using grafana-cli](#using-grafana-cli) paragraph.

If there is no `grafana-cli` tool in your system, plugins can be installed [manually](#manual-installation).

### Table of contents
- [Using grafana-cli](#using-grafana-cli)
  - [Install plugin](#install-update-plugin)
- [Manual installation](#manual-installation)
- [Docker installation](#docker-installation)

### Using grafana-cli

Grafana docs about plugin installation: [https://grafana.com/docs/grafana/latest/cli/#plugins-commands](https://grafana.com/docs/grafana/latest/cli/#plugins-commands).

#### Install / update plugin
```bash
grafana-cli --pluginUrl "https://code.corpglory.net/attachments/fa42eb7f-72b9-4a3e-a60e-33fbf7967b30" plugins install corpglory-dataexporter-app
sudo systemctl restart grafana-server
```

### Manual installation

- Navigate to Grafana plugins directory:
  - For Grafana installed from `.deb`/`.rpm` package:
    - `/var/lib/grafana/plugins`
  - For Grafana installed using Standalone Linux Binaries or source:
    - `<GRAFANA_PATH>/data/plugins`

- Download corpglory-dataexporter-app
```bash
wget https://code.corpglory.net/attachments/fa42eb7f-72b9-4a3e-a60e-33fbf7967b30 -O corpglory-dataexporter-app.tar.gz
```

- Unpack downloaded files
```bash
tar -zxvf corpglory-dataexporter-app.tar.gz
```

- Restart Grafana
  - For Grafana installed from `.deb`/`.rpm` package:
    - `systemctl restart grafana-server`
  - For Grafana installed using Standalone Linux Binaries or source:
    - Stop any running instances of grafana-server
    - Start grafana-server: `cd <GRAFANA_PATH> && ./bin/grafana-server`

### Docker installation

You can install Data Exporter App to Grafana in Docker passing it as the environment variable.

```bash
docker run \
  -p 3000:3000 \
  -e "GF_INSTALL_PLUGINS=https://code.corpglory.net/attachments/fa42eb7f-72b9-4a3e-a60e-33fbf7967b30;corpglory-dataexporter-app" \
  grafana/grafana
```

#### Useful links
- Grafana docs about Docker installation: [https://docs.grafana.org/installation/docker/#installing-plugins-from-other-sources](https://docs.grafana.org/installation/docker/#installing-plugins-from-other-sources)

## Plugin Configuration

- In Grafana, go to Configuration -> Plugins -> Data Exporter App
- Fill "DataExporter backend URL" field with the Data Exporter URL (Please note: the URL should be accessible by Grafana Server)
- Click Connect 
- If Grafana connects to the Data Exporter successfully, you'll see this message: "Plugin is connected! You can now go to a dashboard and add the DataExporter panel there."
- After this:
  - go to a dashboard you'd like to export data from
  - click "Add panel"
  - select Data Exporter Panel

## Support and Consulting

Commercial support, professional services **or any help** — send us your inquiry at ping@corpglory.com

## About CorpGlory Inc.
Grafana Data Exporter is developed by [CorpGlory Inc.](https://corpglory.com/), a company which provides high quality software development, data visualization, Grafana and monitoring consulting.

==> 1.0.10.zip: grafana-data-exporter-app/README.md <==
# Grafana Data Exporter App

Grafana plugin for exporting data from Grafana panels as CSV.

Supported datasources:
- MySQL
- PostgreSQL

We work on expanding this list. If you would like us to support any particular datasource -- please let us know at ping@corpglory.com

## Prerequisites
- [Grafana 9.0.0+](https://grafana.com/grafana/download)
- [Grafana Data Exporter](https://code.corpglory.net/corpglory/grafana-data-exporter)

## Plugin Configuration

- Make sure [Grafana Data Exporter](https://code.corpglory.net/corpglory/grafana-data-exporter) is running, and accessible from Grafana Server
- In Grafana, go to Configuration -> Plugins -> Data Exporter App
- Fill "DataExporter backend URL" field with the Data Exporter URL (Please note: the URL should be accessible from Grafana Server)
- Click Connect 
- If Grafana connects to the Data Exporter successfully, you'll see this message: "Plugin is connected! You can now go to a dashboard and add the DataExporter panel there."

## Plugin Usage
- go to a dashboard you'd like to export data from
- click "Add panel"
- select Data Exporter Panel
- click Add Task
- select timerange and query
- click Export

## Support and Consulting

Commercial support, professional services **or any help** — send us your inquiry at ping@corpglory.com

## About CorpGlory Inc.
Grafana Data Exporter is developed by [CorpGlory Inc.](https://corpglory.com/), a company which provides high quality software development, data visualization, Grafana and monitoring consulting.
